# Generated by roxygen2: do not edit by hand

S3method(AIC,predmicror_fit)
S3method(AIC,predmicror_omnibus_fit)
S3method(BIC,predmicror_fit)
S3method(BIC,predmicror_omnibus_fit)
S3method(as.data.frame,predmicror_fit)
S3method(as.data.frame,predmicror_omnibus_fit)
S3method(coef,predmicror_dynamic_fit)
S3method(coef,predmicror_fit)
S3method(coef,predmicror_omnibus_fit)
S3method(fit_metrics,default)
S3method(fit_metrics,predmicror_dynamic_fit)
S3method(fit_metrics,predmicror_fit)
S3method(fit_metrics,predmicror_omnibus_fit)
S3method(fitted,predmicror_dynamic_fit)
S3method(fitted,predmicror_fit)
S3method(fitted,predmicror_omnibus_fit)
S3method(logLik,predmicror_fit)
S3method(logLik,predmicror_omnibus_fit)
S3method(plot,predmicror_dynamic_fit)
S3method(plot,predmicror_fit)
S3method(predict,predmicror_dynamic_fit)
S3method(predict,predmicror_fit)
S3method(predict,predmicror_omnibus_fit)
S3method(predmicror_augment,default)
S3method(predmicror_augment,predmicror_dynamic_fit)
S3method(predmicror_augment,predmicror_fit)
S3method(predmicror_augment,predmicror_omnibus_fit)
S3method(print,predmicror_dynamic_fit)
S3method(print,predmicror_dynamic_prediction)
S3method(print,predmicror_dynamic_profile)
S3method(print,predmicror_fit)
S3method(print,predmicror_omnibus_fit)
S3method(residuals,predmicror_dynamic_fit)
S3method(residuals,predmicror_fit)
S3method(residuals,predmicror_omnibus_fit)
S3method(summary,predmicror_dynamic_fit)
S3method(summary,predmicror_fit)
S3method(summary,predmicror_omnibus_fit)
S3method(vcov,predmicror_fit)
export(BaranyiFM)
export(BaranyiRM)
export(BuchananRM)
export(CMAW)
export(CMInh)
export(CMPH)
export(CMTI)
export(FangNLM)
export(GeeraerdST)
export(HuangFM)
export(HuangNLM)
export(HuangRGS)
export(HuangRM)
export(RichardsNLM)
export(RossoFM)
export(WeibullM)
export(WeibullMM)
export(WeibullPH)
export(ZwieteringFM)
export(accuracy_factor)
export(bias_factor)
export(compare_models)
export(dynamic_profile)
export(dynamic_sensitivity)
export(fit_cardinal)
export(fit_dynamic_growth)
export(fit_dynamic_inactivation)
export(fit_growth)
export(fit_inactivation)
export(fit_metrics)
export(fit_omnibus)
export(fit_omnibus_growth)
export(fit_omnibus_inactivation)
export(omnibus_secondary)
export(predict_dynamic_growth)
export(predict_dynamic_inactivation)
export(predmicror_assistant)
export(predmicror_assistant_app)
export(predmicror_augment)
export(predmicror_models)
export(validate_omnibus_leave_one_out)
importFrom(Rdpack,reprompt)
importFrom(graphics,lines)
importFrom(graphics,plot)
importFrom(gslnls,gsl_nls)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,coef)
importFrom(stats,fitted)
importFrom(stats,logLik)
importFrom(stats,predict)
importFrom(stats,residuals)
importFrom(stats,vcov)
importFrom(utils,tail)
