predmicror assistant (CLI)

Usage:
  Rscript inst/agent/predmicror_assist.R "How do I fit a Huang model?"

Notes:
- Requires ollama in PATH.
- Defaults to model: llama3-groq-tool-use:8b
- Set OLLAMA_MODEL to override.
